@@ -17,24 +17,14 @@ suppressPackageStartupMessages({
 # genWorkenvir(workflow = "varseq", mydirname = "varseq")
 # setwd("varseq")
 
-## ----download_commands, eval=FALSE------------------------
-# targets <- read.delim(system.file("extdata", "workflows", "varseq", "targetsPE_varseq.txt", package = "systemPipeRdata"), comment.char = "#")
-# source("VARseq_helper.R") # temp file
-# options(timeout = 3600) # increase time limit for downloads
-# commands <- varseq_example_fastq(targets)
-# for (cmd in commands) eval(parse(text = cmd))
-# download_ref(ref="hg38.fa.gz")
-# download_tool(tool="snpEff_latest")
-
 ## ----load_targets_file, eval=TRUE-------------------------
-targetspath <- system.file("extdata", "workflows", "varseq", "targetsPE_varseq.txt", package = "systemPipeRdata")
+targetspath <- system.file("extdata", "targetsPE.txt", package = "systemPipeR")
 targets <- read.delim(targetspath, comment.char = "#")
-targets[1:4, -(5:8)]
+targets[1:4,-c(5,6)]
 
 ## ----project_varseq, eval=FALSE---------------------------
 # library(systemPipeR)
 # sal <- SPRproject()
-# # sal <- SPRproject(resume=TRUE, load.envir=TRUE) # to resume workflow if needed
 # sal <- importWF(sal, file_path = "systemPipeVARseq.Rmd", verbose = FALSE)
 # sal
 
@@ -58,12 +48,16 @@ knitr::include_graphics("results/plotwf_varseq.png")
 ## ----status_varseq, eval=FALSE----------------------------
 # statusWF(sal)
 
-## ----save_sal, eval=FALSE---------------------------------
-# # sal <- write_SYSargsList(sal)
-
 ## ----load_SPR, message=FALSE, eval=FALSE, spr=TRUE--------
+# # Some samples in the test dataset do not work well in VARseq, and VARseq workflow
+# # takes long time to process each sample. To better test and speed up the test workflow,
+# # sample set is reduced to the first 13 samples.
+# # Please REMOVE the next two lines in your real analysis
+# cat(crayon::red$bold("Some samples in targets are removed for test workflow. Please change the template to disable this in your real analysis.\n"))
+# writeLines(readLines("targetsPE.txt")[1:13], "targetsPE.txt")
+# 
 # cat(crayon::blue$bold("To use this workflow, following R packages are expected:\n"))
-# cat(c("'ggplot2', 'dplyr'\n"), sep = "', '")
+# cat(c("'GenomicFeatures", "VariantAnnotation", "GenomicFeatures", "ggbio", "ggplot2'\n"), sep = "', '")
 # ###pre-end
 # appendStep(sal) <- LineWise(
 #     code = {
@@ -72,36 +66,25 @@ knitr::include_graphics("results/plotwf_varseq.png")
 #     step_name = "load_SPR"
 # )
 
-## ----fastqc, eval=FALSE, spr=TRUE-------------------------
-# appendStep(sal) <- SYSargsList(
-#     step_name = "fastqc",
-#     targets = "targetsPE_varseq.txt",
-#     wf_file = "fastqc/workflow_fastqc.cwl",
-#     input_file = "fastqc/fastqc.yml",
-#     dir_path = "param/cwl",
-#     inputvars = c(
-#         FileName1  = "_FASTQ_PATH1_",
-#         FileName2  = "_FASTQ_PATH2_"
-#     ),
+## ----fastq_report_pre, eval=FALSE, message=FALSE, spr=TRUE----
+# appendStep(sal) <- LineWise(
+#     code = {
+#         targets <- read.delim("targetsPE.txt", comment.char = "#")
+#         updateColumn(sal, step = "load_SPR", position = "targetsWF") <- targets
+#         fq_files <- getColumn(sal, "load_SPR", "targetsWF", column = 1)
+#         fqlist <- seeFastq(fastq = fq_files, batchsize = 10000, klength = 8)
+#         png("./results/fastqReport.png", height = 162, width = 288 * length(fqlist))
+#         seeFastqPlot(fqlist)
+#         dev.off()
+#     },
+#     step_name = "fastq_report_pre",
 #     dependency = "load_SPR"
 # )
 
-## ----fastq_report, eval=FALSE, message=FALSE, spr=TRUE----
-# appendStep(sal) <- LineWise(code = {
-#   fastq1 <- getColumn(sal, step = "fastqc", "targetsWF", column = 1)
-#   fastq2 <- getColumn(sal, step = "fastqc", "targetsWF", column = 2)
-#   fastq <- setNames(c(rbind(fastq1, fastq2)), c(rbind(names(fastq1), names(fastq2))))
-#   fqlist <- seeFastq(fastq = fastq, batchsize = 1000, klength = 8)
-#   png("./results/fastqReport_varseq.png", height = 650, width = 288 * length(fqlist))
-#   seeFastqPlot(fqlist)
-#   dev.off()
-# }, step_name = "fastq_report",
-# dependency = "fastqc")
-
 ## ----trimmomatic, eval=FALSE, spr=TRUE--------------------
 # appendStep(sal) <- SYSargsList(
 #     step_name = "trimmomatic",
-#     targets = "targetsPE_varseq.txt",
+#     targets = "targetsPE.txt",
 #     wf_file = "trimmomatic/trimmomatic-pe.cwl",
 #     input_file = "trimmomatic/trimmomatic-pe.yml",
 #     dir_path = "param/cwl",
@@ -110,14 +93,14 @@ knitr::include_graphics("results/plotwf_varseq.png")
 #         FileName2 = "_FASTQ_PATH2_",
 #         SampleName = "_SampleName_"
 #     ),
-#     dependency = c("load_SPR"),
+#     dependency = c("fastq_report_pre"),
 #     run_step = "optional"
 # )
 
 ## ----preprocessing, message=FALSE, eval=FALSE, spr=TRUE----
 # appendStep(sal) <- SYSargsList(
 #     step_name = "preprocessing",
-#     targets = "targetsPE_varseq.txt", dir = TRUE,
+#     targets = "targetsPE.txt", dir = TRUE,
 #     wf_file = "preprocessReads/preprocessReads-pe.cwl",
 #     input_file = "preprocessReads/preprocessReads-pe.yml",
 #     dir_path = "param/cwl",
@@ -126,7 +109,41 @@ knitr::include_graphics("results/plotwf_varseq.png")
 #         FileName2 = "_FASTQ_PATH2_",
 #         SampleName = "_SampleName_"
 #     ),
-#     dependency = c("load_SPR"),
+#     dependency = c("fastq_report_pre"),
+#     run_step = "optional"
+# )
+
+## ----custom_preprocessing_function, eval=FALSE------------
+# appendStep(sal) <- LineWise(
+#     code = {
+#         filterFct <- function(fq, cutoff = 20, Nexceptions = 0) {
+#             qcount <- rowSums(as(quality(fq), "matrix") <= cutoff, na.rm = TRUE)
+#             # Retains reads where Phred scores are >= cutoff with N exceptions
+#             fq[qcount <= Nexceptions]
+#         }
+#         save(list = ls(), file = "param/customFCT.RData")
+#     },
+#     step_name = "custom_preprocessing_function",
+#     dependency = "preprocessing"
+# )
+
+## ----editing_preprocessing, message=FALSE, eval=FALSE-----
+# yamlinput(sal, "preprocessing")$Fct
+# yamlinput(sal, "preprocessing", "Fct") <- "'filterFct(fq, cutoff=20, Nexceptions=0)'"
+# yamlinput(sal, "preprocessing")$Fct ## check the new function
+# cmdlist(sal, "preprocessing", targets = 1) ## check if the command line was updated with success
+
+## ----fastq_report_pos, eval=FALSE, message=FALSE, spr=TRUE----
+# appendStep(sal) <- LineWise(
+#     code = {
+#         fq_files <- getColumn(sal, "preprocessing", "outfiles", column = 1) ## get outfiles path
+#         fqlist <- seeFastq(fastq = fq_files, batchsize = 10000, klength = 8)
+#         png("./results/fastqReport_pos.png", height = 18, width = 4 * length(fqlist))
+#         seeFastqPlot(fqlist)
+#         dev.off()
+#     },
+#     step_name = "fastq_report_pos",
+#     dependency = "trimmomatic",
 #     run_step = "optional"
 # )
 
@@ -163,7 +180,7 @@ knitr::include_graphics("results/plotwf_varseq.png")
 ## ----bwa_alignment, eval=FALSE, spr=TRUE------------------
 # appendStep(sal) <- SYSargsList(
 #     step_name = "bwa_alignment",
-#     targets = "targetsPE_varseq.txt",
+#     targets = "targetsPE.txt",
 #     wf_file = "gatk/workflow_bwa-pe.cwl",
 #     input_file = "gatk/gatk.yaml",
 #     dir_path = "param/cwl",
@@ -181,23 +198,20 @@ knitr::include_graphics("results/plotwf_varseq.png")
 #         bampaths <- getColumn(sal, step = "bwa_alignment", "outfiles", column = "samtools_sort_bam")
 #         fqpaths <- getColumn(sal, step = "bwa_alignment", "targetsWF", column = "FileName1")
 #         read_statsDF <- alignStats(args = bampaths, fqpaths = fqpaths, pairEnd = TRUE)
-#         write.table(read_statsDF, "results/alignStats_varseq.xls", row.names = FALSE, quote = FALSE, sep = "\t")
+#         write.table(read_statsDF, "results/alignStats.xls", row.names = FALSE, quote = FALSE, sep = "\t")
 #     },
 #     step_name = "align_stats",
 #     dependency = "bwa_alignment",
 #     run_step = "optional"
 # )
 
-## ----align_stats_view, eval=TRUE--------------------------
-read.table("results/alignStats_varseq.xls", header = TRUE)[1:4,]
-
 ## ----bam_urls, eval=FALSE, spr=TRUE-----------------------
 # appendStep(sal) <- LineWise(
 #     code = {
 #         bampaths <- getColumn(sal, step = "bwa_alignment", "outfiles", column = "samtools_sort_bam")
 #         symLink2bam(
-#             sysargs = bampaths, htmldir = c("~/.html/", "<somedir>/"),
-#             urlbase = "<base_url>/~<username>/",
+#             sysargs = bampaths, htmldir = c("~/.html/", "somedir/"),
+#             urlbase = "http://cluster.hpcc.ucr.edu/~tgirke/",
 #             urlfile = "./results/IGVurl.txt"
 #         )
 #     },
@@ -209,7 +223,7 @@ read.table("results/alignStats_varseq.xls", header = TRUE)[1:4,]
 ## ----fastq2ubam, eval=FALSE, spr=TRUE---------------------
 # appendStep(sal) <- SYSargsList(
 #     step_name = "fastq2ubam",
-#     targets = "targetsPE_varseq.txt",
+#     targets = "targetsPE.txt",
 #     wf_file = "gatk/workflow_gatk_fastq2ubam.cwl",
 #     input_file = "gatk/gatk.yaml",
 #     dir_path = "param/cwl",
@@ -330,10 +344,23 @@ read.table("results/alignStats_varseq.xls", header = TRUE)[1:4,]
 #     dependency = c("hap_caller", "filter")
 # )
 
+## ----create_vcf_BCFtool, eval=FALSE, spr=TRUE-------------
+# appendStep(sal) <- SYSargsList(
+#     step_name = "create_vcf_BCFtool",
+#     targets = "bwa_alignment", dir = TRUE,
+#     wf_file = "workflow-bcftools/workflow_bcftools.cwl",
+#     input_file = "workflow-bcftools/bcftools.yml",
+#     dir_path = "param/cwl",
+#     inputvars = c(bwa_men_sam = "_bwasam_", SampleName = "_SampleName_"),
+#     rm_targets_col = c("preprocessReads_1", "preprocessReads_2"),
+#     dependency = "bwa_alignment",
+#     run_step = "optional"
+# )
+
 ## ----inspect_vcf, eval=FALSE------------------------------
 # library(VariantAnnotation)
 # vcf_raw <- getColumn(sal, "create_vcf")
-# vcf <- readVcf(vcf_raw[1], "Homo sapiens")
+# vcf <- readVcf(vcf_raw[1], "A. thaliana")
 # vcf
 # vr <- as(vcf, "VRanges")
 # vr
@@ -343,249 +370,127 @@ read.table("results/alignStats_varseq.xls", header = TRUE)[1:4,]
 #     code = {
 #         vcf_raw <- getColumn(sal, "create_vcf")
 #         library(VariantAnnotation)
-#         filter <- "totalDepth(vr) >= 20 & (altDepth(vr) / totalDepth(vr) >= 0.8)"
-#         vcf_filter <- suppressWarnings(filterVars(vcf_raw, filter, organism = "Homo sapiens", out_dir = "results/vcf_filter"))
+#         filter <- "totalDepth(vr) >= 2 & (altDepth(vr) / totalDepth(vr) >= 0.8)"
+#         vcf_filter <- suppressWarnings(filterVars(vcf_raw, filter, organism = "A. thaliana", out_dir = "results/vcf_filter"))
+#         # dump the filtered path variable to running enviornment so
+#         # other sysArg steps can get its values
+#         updateColumn(sal, 'create_vcf', "outfiles") <- data.frame(vcf_filter=vcf_filter)
 #     },
 #     step_name = "filter_vcf",
-#     dependency = "create_vcf",
+#     dependency = "create_vcf"
+# )
+
+## ----filter_vcf_BCFtools, eval=FALSE, spr=TRUE------------
+# appendStep(sal) <- LineWise(
+#     code = {
+#         vcf_raw <- getColumn(sal, step = "create_vcf_BCFtool",
+#                              position = "outfiles", column = "bcftools_call")
+#         library(VariantAnnotation)
+#         filter <- "rowSums(vr) >= 2 & (rowSums(vr[,3:4])/rowSums(vr[,1:4]) >= 0.8)"
+#         vcf_filter_bcf <- suppressWarnings(filterVars(vcf_raw, filter, organism = "A. thaliana", out_dir = "results/vcf_filter_BCFtools", varcaller = "bcftools"))
+# 
+#         updateColumn(sal, 'create_vcf', "outfiles") <- data.frame(vcf_filter_bcf=vcf_filter_bcf)
+#     },
+#     step_name = "filter_vcf_BCFtools",
+#     dependency = "create_vcf_BCFtool",
 #     run_step = "optional"
 # )
 
 ## ----check_filter, eval=FALSE-----------------------------
 # copyEnvir(sal, "vcf_raw", globalenv())
 # copyEnvir(sal, "vcf_filter", globalenv())
-# length(as(readVcf(vcf_raw[1], genome = "Homo sapiens"), "VRanges")[, 1])
-# length(as(readVcf(vcf_filter[1], genome = "Homo sapiens"), "VRanges")[, 1])
+# length(as(readVcf(vcf_raw[1], genome = "Ath"), "VRanges")[, 1])
+# length(as(readVcf(vcf_filter[1], genome = "Ath"), "VRanges")[, 1])
 
-## ----summary_filter, eval=FALSE, spr=TRUE-----------------
-# appendStep(sal) <- LineWise(
-#     code = {
-# 
-#           # read in the cohort VCF file
-#           vcf_all <- suppressWarnings(VariantAnnotation::readVcf("./results/samples_filter.vcf.gz", "Homo sapiens"))
-# 
-#           filter_values <- VariantAnnotation::filt(vcf_all)
-#           filter_values[is.na(filter_values)] <- "" # ensure character comparisons work
-#           overall_counts <- table(filter_values) |>
-#              dplyr::as_tibble() |>
-#              dplyr::arrange(dplyr::desc(n))
-# 
-#           vcf_all_ft <- VariantAnnotation::geno(vcf_all)$FT
-#           passes_per_sample <- apply(vcf_all_ft, 2, function(x) sum(x == "PASS", na.rm = TRUE))
-#           fails_per_sample <- apply(vcf_all_ft, 2, function(x) sum(x != "PASS", na.rm = TRUE))
-#           sample_filter_summary <- dplyr::tibble(
-#               sample = names(passes_per_sample),
-#               passed = passes_per_sample,
-#               filtered = fails_per_sample
-#           )
-# 
-#           write.table(overall_counts, file = "results/summary_filter_overall.tsv", sep = "\t", quote = FALSE, row.names = FALSE)
-#           write.table(sample_filter_summary, file = "results/summary_filter_per_sample.tsv", sep = "\t", quote = FALSE, row.names = FALSE)
-# 
-#           library(ggplot2)
-#           source("VARseq_helper.R")
-#           png("results/summary_filter_plot.png", width = 800, height = 600)
-#           p_filter <- plot_summary_filter_plot(sample_filter_summary)
-#           print(p_filter)
-#           dev.off()
-# 
-#           # clean up RAM
-#           try(rm(vcf_all, vcf_all_ft, filter_values, passes_per_sample, fails_per_sample), silent = TRUE)
-#           invisible(gc())
-# 
-#     },
-#     step_name = "summary_filter",
-#     dependency = "filter"
-# )
+## ----annotate_basics, eval=FALSE--------------------------
+# library("GenomicFeatures")
+# # comment the next line if optional step "filter_vcf" is included
+# vcf_filter <- getColumn(sal, "create_vcf")
+# # uncomment the next line if optional step "filter_vcf" is included
+# # copyEnvir(sal, "vcf_filter", globalenv())
+# txdb <- loadDb("./data/tair10.sqlite")
+# vcf <- readVcf(vcf_filter[1], "A. thaliana")
+# locateVariants(vcf, txdb, CodingVariants())
+
+## ----annotate_basics_non-synon, eval=FALSE----------------
+# fa <- FaFile("data/tair10.fasta")
+# predictCoding(vcf, txdb, seqSource = fa)
 
 ## ----annotate_vcf, eval=FALSE, spr=TRUE-------------------
-# appendStep(sal) <- SYSargsList(
+# appendStep(sal) <- LineWise(
+#     code = {
+#         # get the filtered vcf path from R running environment
+#         copyEnvir(sal, "vcf_filter", globalenv())
+#         library("GenomicFeatures")
+#         txdb <- loadDb("./data/tair10.sqlite")
+#         fa <- FaFile("data/tair10.fasta")
+#         vcf_anno <- suppressMessages(suppressWarnings(variantReport(vcf_filter, txdb = txdb, fa = fa, organism = "A. thaliana", out_dir = "results/vcf_anno")))
+#     },
 #     step_name = "annotate_vcf",
-#     targets = "create_vcf", dir = TRUE,
-#     wf_file = "gatk/snpeff.cwl",
-#     input_file = "gatk/gatk.yaml",
-#     dir_path = "param/cwl",
-#     inputvars = c(SampleName = "_SampleName_", vcf_raw = "_vcf_raw_"),
-#     dependency = c("create_vcf")
+#     dependency = "filter_vcf"
 # )
 
+## ----view_annotation, eval=FALSE--------------------------
+# copyEnvir(sal, "vcf_anno", globalenv())
+# read.delim(vcf_anno[1])[38:40, ]
+
 ## ----combine_var, eval=FALSE, spr=TRUE--------------------
 # appendStep(sal) <- LineWise(
-#   code = {
-#     vcf_anno <- getColumn(sal, "annotate_vcf", position = "outfiles", column = "ann_vcf")
-# 
-#     clean_vcf_file <- function(path) {
-#       lines <- readLines(path, warn = FALSE)
-#       if (!length(lines)) return(path)
-#       header_start <- which(grepl("^##fileformat=", lines, perl = TRUE))[1]
-#       if (is.na(header_start) || header_start <= 1) return(path)
-#       writeLines(lines[header_start:length(lines)], path)
-#       path
-#     }
-# 
-#     vcf_anno <- vapply(vcf_anno, clean_vcf_file, FUN.VALUE = character(1))
-#     vr_from_vcf <- function(path) {
-#       message("Importing annotated VCF: ", path)
-#       vcf <- suppressWarnings(VariantAnnotation::readVcf(path, "Homo sapiens"))
-# 
-#       ft <- VariantAnnotation::geno(vcf)$FT
-#       if (!is.null(ft) && !isTRUE(is.character(ft))) {
-#         ft_vec <- as.character(ft)
-#         ft_clean <- matrix(ft_vec, ncol = 1)
-#         if (!is.null(dim(ft))) {
-#           ft_clean <- matrix(ft_vec, nrow = nrow(ft), dimnames = dimnames(ft))
-#         }
-#         VariantAnnotation::geno(vcf)$FT <- ft_clean
-#       }
-#       suppressWarnings(as(vcf, "VRanges"))
-#     }
-# 
-#     vcf_vranges <- lapply(vcf_anno, vr_from_vcf)
-#   },
-#   step_name = "combine_var",
-#   dependency = "annotate_vcf"
+#     code = {
+#         combineDF <- combineVarReports(vcf_anno, filtercol = c(Consequence = "nonsynonymous"))
+#         write.table(combineDF, "./results/combineDF_nonsyn.tsv", quote = FALSE, row.names = FALSE, sep = "\t")
+#     },
+#     step_name = "combine_var",
+#     dependency = "annotate_vcf"
 # )
 
 ## ----summary_var, eval=FALSE, spr=TRUE--------------------
 # appendStep(sal) <- LineWise(
 #     code = {
-#         source("VARseq_helper.R")
-#         summary_var <- extract_var_table(vcf_vranges)
-#         utils::write.table(summary_var, file = "results/variant_summary_long.tsv", sep = "\t", quote = FALSE, row.names = FALSE)
+#         write.table(varSummary(vcf_anno), "./results/variantStats.tsv", quote = FALSE, col.names = NA, sep = "\t")
 #     },
 #     step_name = "summary_var",
 #     dependency = "combine_var"
 # )
 
-## ----plot_var_consequence, eval=FALSE, spr=TRUE-----------
-# appendStep(sal) <- LineWise(
-#     code = {
-#         library(ggplot2)
-#         effect_counts <- summary_var |>
-#           dplyr::count(sample, effect, name = "n")
-# 
-#         png("./results/var_consequence_log.png", width = 1000, height = 600)
-#         p_var_consequence_log <- ggplot(effect_counts, aes(sample, n, fill = effect)) +
-#         geom_col(position = "dodge", alpha = 0.8) +
-#         geom_text(aes(label = scales::comma(n)), position = position_dodge(width = 0.9), vjust = -0.2, size = 3) +
-#         scale_y_continuous(trans = "log10", labels = scales::comma_format()) +
-#         labs(y = "Variant count (log10 scale)", title = "Variant consequences (log scale)") +
-#         theme_minimal() +
-#         theme(axis.text.x = element_text(angle = 45, hjust = 1))
-#         print(p_var_consequence_log)
-#         dev.off()
-#     },
-#     step_name = "plot_var_consequence",
-#     dependency = "summary_var"
-# )
-
-## ----plot_var_stats, eval=FALSE, spr=TRUE-----------------
-# appendStep(sal) <- LineWise(
-#     code = {
-#         library(ggplot2)
-#         plot_summary_data <- summary_var |>
-#           dplyr::filter(
-#             consequence %in% c(
-#               "nonsynonymous_variant", "stop_gained", "frameshift_variant",
-#               "splice_acceptor_variant", "splice_donor_variant",
-#               "start_lost", "stop_lost"
-#             ),
-#             effect == "HIGH"
-#           ) |>
-#           dplyr::mutate(
-#             sample = factor(sample, levels = getColumn(sal, step = "annotate_vcf", position = "targetsWF", column = "SampleName")),
-#             sex = getColumn(sal, step = "annotate_vcf", position = "targetsWF", column = "Factor")[sample]
-#           )
-# 
-#         png("./results/var_summary.png")
-#         p_var_summary <- ggplot(plot_summary_data) +
-#           geom_bar(aes(x = sample, fill = sex), alpha = 0.75) +
-#           scale_fill_brewer(palette = "Set2") +
-#           theme_minimal()
-#         print(p_var_summary)
-#         dev.off()
-#     },
-#     step_name = "plot_var_stats",
-#     dependency = "summary_var"
-# )
-
-## ----plot_var_boxplot, eval=FALSE, spr=TRUE---------------
-# appendStep(sal) <- LineWise(
-#     code = {
-#         source("VARseq_helper.R")
-#         # change the sample and group columns as needed
-#         p_summary_boxplot <- plot_summary_boxplot(plot_summary_data, sample_col = "sample", group_col = "sex")
-#         library(ggplot2)
-#         png("./results/var_summary_boxplot.png")
-#         print(p_summary_boxplot)
-#         dev.off()
-#     },
-#     step_name = "plot_var_boxplot",
-#     dependency = "plot_var_stats"
-# )
-
 ## ----venn_diagram, eval=FALSE, spr=TRUE-------------------
 # appendStep(sal) <- LineWise(
 #     code = {
-#         top_n <- min(3, length(variant_tables))
-#         selected_tables <- variant_tables[seq_len(top_n)]
-#         if (is.null(names(selected_tables)) || any(!nzchar(names(selected_tables)))) {
-#             names(selected_tables) <- paste0("Sample_", seq_along(selected_tables))
-#         }
-# 
-#         variant_sets <- lapply(selected_tables, function(df) {
-#             if (!nrow(df)) return(character(0))
-#             unique(paste0(df$seqnames, ":", df$start, "_", df$ref, "/", df$alt))
-#         })
-# 
-#         vennset <- overLapper(variant_sets, type = "vennsets")
+#         ## make a list of first three samples
+#         varlist <- sapply(names(vcf_anno[1:3]), function(x) as.character(read.delim(vcf_anno[x])$VARID))
+#         vennset <- overLapper(varlist, type = "vennsets")
 #         png("./results/vennplot_var.png")
-#         vennPlot(vennset, mymain = "Venn Plot of First 3 Samples", mysub = "", colmode = 2, ccol = c("red", "blue"))
+#         vennPlot(list(vennset), mymain = "Venn Plot of First 3 Samples", mysub = "", colmode = 2, ccol = c("red", "blue"))
 #         dev.off()
 #     },
 #     step_name = "venn_diagram",
-#     dependency = "summary_var"
+#     dependency = "annotate_vcf"
 # )
 
 ## ----plot_variant, eval=FALSE, spr=TRUE-------------------
 # appendStep(sal) <- LineWise(
 #     code = {
-#         source("VARseq_helper.R")
-#         first_high <- summary_var |>
-#           dplyr::filter(effect == "HIGH") |>
-#           head(n = 1)
+#         # get the filtered vcf path from R running environment
+#         copyEnvir(sal, "vcf_filter", globalenv())
 #         library(ggbio)
 #         library(VariantAnnotation)
-#         mychr <- as.character(first_high$seqnames)
-#         mystart <- as.numeric(first_high$start) - 500
-#         myend <- as.numeric(first_high$end) + 500
-#         bam_path <- getColumn(sal, "fix_tag")[first_high$sample]
-#         vcf_path <- getColumn(sal, step = "create_vcf")[first_high$sample]
-# 
-#         vcf <- suppressWarnings(readVcf(vcf_path, "Homo sapiens"))
-#         ga <- readGAlignments(bam_path, use.names = TRUE, param = ScanBamParam(which = GRanges(mychr, IRanges(mystart, myend))))
-#         vcf_chr <- normalize_ft(simplify_info(vcf[seqnames(vcf) == mychr]))
-#         vr <- suppressWarnings(as(vcf_chr, "VRanges"))
-#         vr_region <- vr[start(vr) >= mystart & end(vr) <= myend]
-#         if (!length(vr_region)) {
-#             vr_region <- vr
-#         }
+#         mychr <- "ChrM"
+#         mystart <- 19000
+#         myend <- 21000
+#         bams <- getColumn(sal, "fix_tag")
+#         vcf <- suppressWarnings(readVcf(vcf_filter["M6B"], "A. thaliana"))
+#         ga <- readGAlignments(bams["M6B"], use.names = TRUE, param = ScanBamParam(which = GRanges(mychr, IRanges(mystart, myend))))
 #         p1 <- autoplot(ga, geom = "rect")
 #         p2 <- autoplot(ga, geom = "line", stat = "coverage")
-#         p3 <- autoplot(vr_region, type = "fixed") +
+#         p3 <- autoplot(vcf[seqnames(vcf) == mychr], type = "fixed") +
 #             xlim(mystart, myend) +
 #             theme(legend.position = "none", axis.text.y = element_blank(), axis.ticks.y = element_blank())
-#         p1_3 <- tracks(
-#             place_holder = ggplot2::ggplot(),
-#             Reads = p1,
-#             Coverage = p2,
-#             Variant = p3,
-#             heights = c(0, 0.3, 0.2, 0.1)
-#         ) + ylab("")
-#         ggbio::ggsave(p1_3, filename = "./results/plot_variant.png", units = "in")
+#         p4 <- autoplot(loadDb("./data/tair10.sqlite"), which = GRanges(mychr, IRanges(mystart, myend)), names.expr = "gene_id")
+#         p1_4 <- tracks(Reads = p1, Coverage = p2, Variant = p3, Transcripts = p4, heights = c(0.3, 0.2, 0.1, 0.35)) + ylab("")
+#         ggbio::ggsave(p1_4, filename = "./results/plot_variant.png", units = "in")
 #     },
 #     step_name = "plot_variant",
-#     dependency = "summary_var"
+#     dependency = "filter_vcf"
 # )
 
 ## ----sessionInfo, eval=FALSE, spr=TRUE--------------------
@@ -603,14 +508,14 @@ read.table("results/alignStats_varseq.xls", header = TRUE)[1:4,]
 # # wall time in mins, memory in MB
 # resources <- list(conffile=".batchtools.conf.R",
 #                   template="batchtools.slurm.tmpl",
-#                   Njobs=8,
+#                   Njobs=18,
 #                   walltime=120,
 #                   ntasks=1,
 #                   ncpus=4,
 #                   memory=1024,
 #                   partition = "short"
 #                   )
-# sal <- addResources(sal, c("bwa_alignment"), resources = resources)
+# sal <- addResources(sal, c("hisat2_mapping"), resources = resources)
 # sal <- runWF(sal)
 
 ## ----plotWF, eval=FALSE-----------------------------------
@@ -623,7 +528,7 @@ read.table("results/alignStats_varseq.xls", header = TRUE)[1:4,]
 ## ----logsWF, eval=FALSE-----------------------------------
 # sal <- renderLogs(sal)
 
-## ----list_tools, eval=TRUE--------------------------------
+## ----list_tools-------------------------------------------
 if(file.exists(file.path(".SPRproject", "SYSargsList.yml"))) {
     local({
         sal <- systemPipeR::SPRproject(resume = TRUE)
@@ -633,7 +538,7 @@ if(file.exists(file.path(".SPRproject", "SYSargsList.yml"))) {
 } else {
     cat(crayon::blue$bold("Tools and modules required by this workflow are:\n"))
     cat(c("trimmomatic/0.39", "samtools/1.14", "gatk/4.2.0.0", "bcftools/1.15", 
-          "bwa/0.7.17", "snpEff/5.3"), sep = "\n")
+          "bwa/0.7.17"), sep = "\n")
 }
 
 ## ----report_session_info, eval=TRUE-----------------------
